"use strict";

var logger = require('./../logger');
var Configuration = require('../Configuration');

/**
 * Object representing information needed for constructing {@link CustomMap}
 * objects.
 */
function CustomMapOptions(params) {
  if (params.map === undefined) {
    logger.error("map must be defined");
  }
  this._map = params.map;

  if (params.configuration === undefined) {
    logger.error("configuration must be defined");
    this.setConfiguration(new Configuration());
  } else {
    this.setConfiguration(params.configuration);
  }

  if (params.hideDiv !== undefined) {
    this._hideDiv = params.hideDiv;
  } else {
    this._hideDiv = null;
  }

  if (params.overviewDiv !== undefined) {
    this._overviewDiv = params.overviewDiv;
  } else {
    this._overviewDiv = null;
  }

  if (params.markerOptimization !== undefined) {
    if (typeof params.markerOptimization === "boolean") {
      this._markerOptimization = params.markerOptimization;
    } else {
      logger.warn("markerOptimization must be of type boolean");
      this._markerOptimization = true;
    }
  } else {
    this._markerOptimization = true;
  }

  if (params.bigLogo !== undefined) {
    if (typeof params.bigLogo === "boolean") {
      this._bigLogo = params.bigLogo;
    } else {
      logger.warn("bigLogo must be of type boolean");
      this._bigLogo = false;
    }
  } else {
    this._bigLogo = false;
  }

  if (params.customTouchInterface !== undefined) {
    if (typeof params.customTouchInterface === "boolean") {
      this._customTouchInterface = params.customTouchInterface;
    } else {
      logger.warn("customTouchInterface must be of type boolean");
      this._customTouchInterface = false;
    }
  } else {
    this._customTouchInterface = false;
  }
};

CustomMapOptions.prototype.getMap = function() {
  return this._map;
};

CustomMapOptions.prototype.isMarkerOptimization = function() {
  return this._markerOptimization;
};

CustomMapOptions.prototype.isBigLogo = function() {
  return this._bigLogo;
};
CustomMapOptions.prototype.isCustomTouchInterface = function() {
  return this._customTouchInterface;
};

CustomMapOptions.prototype.getOverviewDiv = function() {
  return this._overviewDiv;
};
CustomMapOptions.prototype.getConfiguration = function() {
  return this._configuration;
};
CustomMapOptions.prototype.setConfiguration = function(configuration) {
  this._configuration = configuration;
};
CustomMapOptions.prototype.getHideDiv = function() {
  return this._hideDiv;
};

module.exports = CustomMapOptions;
