"use strict";

var logger = require('../../logger');

/**
 * Class representing alias data.
 * 
 * @param javaObject
 *            object deserialized ajax query to the server side
 */
function Alias(javaObject) {
  this.id = javaObject.idObject;
  this._modelId = javaObject.modelId;
	if (javaObject.bounds!=null) {
	  this.x = javaObject.bounds.x;
	  this.y = javaObject.bounds.y;
	  this.width = javaObject.bounds.width;
	  this.height = javaObject.bounds.height;
	}

  if (this._modelId == null) {
    logger.error("ModelId is not defined for alias", javaObject);
  }

  if (javaObject.name == null) {
    this.completness = "SIMPLE";
  } else {
    this.update(javaObject);
  }
};

/**
 * Updates alias with full data information. This function should be called when
 * full informatin about alias is retrieved from server.
 * 
 * @param javaObject
 *            object representing data from server side
 */
Alias.prototype.update = function(javaObject) {
  if (javaObject.name == null) {
    return;
  }
  this.description = javaObject.notes;
  this.type = javaObject.type;
  this.symbol = javaObject.symbol;
  this.fullName = javaObject.fullName;
  this.abbreviation = javaObject.abbreviation;
  this.formula = javaObject.formula;
  this.name = javaObject.name;
  this.synonyms = javaObject.synonyms;
  this.formerSymbols = javaObject.formerSymbols;
  this.references = javaObject.references;
  this.other = javaObject.other;
  this.completness = "FULL";
};

/**
 * Returns identifier of the alias.
 * 
 * @returns identifier of the alias
 */
Alias.prototype.getId = function() {
  return this.id;
};

/**
 * Returns model identifier where {@link Alias} is located.
 * 
 * @returns model identifier where {@link Alias} is located
 */
Alias.prototype.getModelId = function() {
  return this._modelId;
};

Alias.prototype.getType = function() {
  return this.type;
};

Alias.prototype.setType = function(type) {
  this.type = type;
};

module.exports = Alias;

