"use strict";

/**
 * Class representing data in a specific layout.
 */
function LayoutData(layoutId, name) {
  this.id = layoutId;
  this.name = name;
  this.aliases = [];
  this.aliasById = [];
  this.reactions = [];
};

/**
 * Adds alias to the {@link LayoutData}
 * 
 * @param layoutAlias
 *            information about alias in a layout
 */
LayoutData.prototype.addAlias = function(layoutAlias) {
  this.aliases.push(layoutAlias);
  this.aliasById[layoutAlias.id] = layoutAlias;
};

/**
 * Adds reaction to the {@link LayoutData}
 * 
 * @param layoutReaction
 *            information about reaction in a layout
 */
LayoutData.prototype.addReaction = function(layoutReaction) {
  this.reactions.push(layoutReaction);
};

LayoutData.prototype.getId = function() {
  return this.id;
};

LayoutData.prototype.updateAlias = function(layoutAlias) {
  if (this.aliasById[layoutAlias.getId()] == null) {
    logger.warn("Cannot update alias, it doesn't exist. Alias: "+layoutAlias);
  } else {
    this.aliasById[layoutAlias.id].update(layoutAlias);
  }

};
module.exports = LayoutData;

