"use strict";

/**
 * Object representing information for specific point on the map.
 */
function PointData(javaObject, modelId) {
  if (javaObject instanceof google.maps.Point) {
    this._point = javaObject;
  } else {
    var tmp = javaObject.idObject;
    var tmp = javaObject.idObject.replace("Point2D.Double", "");
    tmp = JSON.parse(tmp);
    var x = parseFloat(tmp[0]).toFixed(2);
    var y = parseFloat(tmp[1]).toFixed(2);
    this._point = new google.maps.Point(x, y);
  }
  this._id = "(" + this._point.x + ", " + this._point.y + ")";
  this._modelId = modelId;
};

/**
 * Returns identifier of the object.
 * 
 * @returns {google.maps.Point} that is identifier of the object
 */
PointData.prototype.getId = function() {
  return this._id;
};

/**
 * Returns point to which this object corresponds.
 * 
 * @returns {google.maps.Point} to which this object corresponds
 */
PointData.prototype.getPoint = function() {
  return this._point;
};

PointData.prototype.getModelId = function() {
  return this._modelId;
};

module.exports = PointData;
