"use strict";

var logger = require('../../logger');

/**
 * Class representing reaction data.
 * 
 * @param javaObject
 *            object deserialized from ajax query to the server side
 */
function Reaction(javaObject) {
  this.id = javaObject.idObject;
  this.startLines = [];
  this.endLines = [];
  this.midLines = [];
  for (var i = 0; i < javaObject.lines.length; i++) {
    var line = javaObject.lines[i];
    if (line.type == "START") {
      this.startLines.push(line);
    } else if (line.type == "END") {
      this.endLines.push(line);
    } else if (line.type == "MIDDLE") {
      this.midLines.push(line);
    } else {
      logger.error("Unknown line type: " + line.type);
    }
  }
  if (javaObject instanceof Reaction) {
    this.setCenter(javaObject.getCenter());
    this.setModelId(javaObject.getModelId());
  } else {
    this.setCenter(javaObject.centerPoint);
    this.setModelId(javaObject.modelId);
  }
};

Reaction.prototype.getId = function() {
  return this.id;
};

Reaction.prototype.getCenter = function() {
  return this._center;
};

Reaction.prototype.setCenter = function(center) {
	if (center == null) {
		logger.error("Setting undefined center: ",center);
	}
  this._center = center;
};

Reaction.prototype.getModelId = function() {
  return this._modelId;
};

Reaction.prototype.setModelId = function(modelId) {
  this._modelId = modelId;
};

module.exports = Reaction;

