"use strict";

var AbstractMarker = require('./AbstractMarker');

/**
 * This class describes Google maps marker (connected to {@link Alias}) that is
 * visualized on the map.
 */
function AliasMarker(id, icon, aliasData, map) {
  AbstractMarker.call(this, icon, map);
  // id of the alias to which marker is connected
  this._id = id;
  // data about the Alias connected to the marker
  this._aliasData = aliasData;
  // google.maps.Marker object
  this._marker = null;
  if (this._aliasData != null) {
    this.init();
    this.show();
  }
};
AliasMarker.prototype = Object.create(AbstractMarker.prototype);
AliasMarker.prototype.constructor = AliasMarker;

/**
 * Returns identifier of this object.
 * 
 * @returns identifier of this object
 */
AliasMarker.prototype.getId = function() {
  return this._id;
};

/**
 * Returns {@link Alias} data for this marker.
 * 
 * @returns {@link Alias} data for this marker
 */
AliasMarker.prototype.getAliasData = function() {
  return this._aliasData;
};

/**
 * Sets {@link Alias} data for this marker.
 * 
 * @param data
 *            {@link Alias} data for this marker
 */
AliasMarker.prototype.setAliasData = function(data) {
  this._aliasData = data;
};

/**
 * Returns coordinates where marker is poiting.
 * 
 * @returns {google.maps.Point} - coordinates where marker is poiting
 */
AliasMarker.prototype.getCoordinates = function() {
  return new google.maps.Point(this._aliasData.x + this._aliasData.width / 2,
      this._aliasData.y + this._aliasData.height / 2);
};

/**
 * Function returning string marker type.
 * 
 * @returns string marker type
 */
AliasMarker.prototype.getType = function() {
  return "ALIAS";
};

module.exports = AliasMarker;

