"use strict";

var AbstractInfoWindow = require('./AbstractInfoWindow');
var PointMarker = require('../marker/PointMarker');

function PointInfoWindow(pointMarker, map) {
  // call super constructor
  AbstractInfoWindow.call(this, pointMarker, map);

  if (pointMarker instanceof PointMarker) {
    this.pointData = pointMarker.getPointData();
  } else {
    this.pointData = pointMarker;
  }

  if (this.pointData != null) {
    var point = this.pointData.getPoint();
    var latLng = this.getCustomMap().fromPointToLatLng(point);
    this.googleInfowindow = new google.maps.InfoWindow({
      content : this.content,
      position : latLng
    });
    this.googleInfowindow.open(this.customMap.map, this.getGoogleMarker());
  } else {
    logger.warn("Opening window without alias specified");
  }
  this.update();
};

PointInfoWindow.prototype = Object.create(AbstractInfoWindow.prototype);
PointInfoWindow.prototype.constructor = PointInfoWindow;

PointInfoWindow.prototype.createContentDiv = function() {
  var result = document.createElement("div");
  var title = document.createElement("h3");
  title.innerHTML = "Point: " + this.pointData.getPoint();
  result.appendChild(title);

  return result;
};

PointInfoWindow.prototype.getOverlaysData = function() {
  return this.getCustomMap().getTopMap().getOverlayDataForPoint(this.pointData);
};

/**
 * Method returning identifier of the object for which this window was created.
 */
PointInfoWindow.prototype.getElementId = function() {
  if (this.pointData != null) {
    return this.pointData.getId();
  } else {
    return null;
  }
};

/**
 * Method returning type of the object for which this window was created.
 */
PointInfoWindow.prototype.getElementType = function() {
  return "POINT";
};

module.exports = PointInfoWindow;
