"use strict";

var logger = require('../../logger');

var AbstractInfoWindow = require('./AbstractInfoWindow');
var ReactionMarker = require('../marker/ReactionMarker');

/**
 * Class representing info window that should be opened when clicking on
 * reaction.
 */
function ReactionInfoWindow(reactionData, map) {
  // call super constructor
  AbstractInfoWindow.call(this, reactionData, map);

  if (reactionData instanceof ReactionMarker) {
    this._reactionData = reactionData.getReactionData();
  } else {
    this._reactionData = reactionData;
  }

  if (this._reactionData != null) {
    var point = new google.maps.Point(this._reactionData.getCenter().x, this._reactionData.getCenter().y);
    var latLng = this.customMap.fromPointToLatLng(point);
    this.googleInfowindow = new google.maps.InfoWindow({
      content : this.content,
      position : latLng
    });
    this.googleInfowindow.open(this.customMap.map, this.getGoogleMarker());
  } else {
    logger.warn("Opening window without reaction specified");
  }
  this.update(this._reactionData);
};

ReactionInfoWindow.prototype = Object.create(AbstractInfoWindow.prototype);
ReactionInfoWindow.prototype.constructor = ReactionInfoWindow;

/**
 * Methods that creates and return html code with the content of the window.
 * 
 * @returns {String} representing html code for content of the info window
 */
ReactionInfoWindow.prototype.createContentDiv = function() {
  if (this._reactionData != null) {
    var content = document.createElement("div");
/*    var title = document.createElement("h3");
    title.innerHTML = "ReactionInfoWindow is not yet implemented.";
    content.appendChild(title)*/
    return content;
  } else {
    return null;
  }
};

/**
 * Returns array with data taken from all known {@link OverlayCollection}.
 * 
 * @returns array with data from {@link OverlayCollection}
 */
ReactionInfoWindow.prototype.getOverlaysData = function(general) {
  if (this._reactionData != null) {
    return this.getCustomMap().getTopMap().getOverlayDataForReaction(this._reactionData,
        general);
  } else {
    return null;
  }
};

module.exports = ReactionInfoWindow;

