'use strict';

var functions = require('./Functions');

var Configuration = require('./Configuration');
var CustomMap = require('./map/CustomMap');
var OverlayCollection = require('./map/overlay/OverlayCollection');

var OriginalGuiConnector = require('./GuiConnector');
var OriginalServerConnector = require('./ServerConnector');

var logger = require('./logger');

function processUrlGetParams() {
  if (GuiConnector.getParams["submap"] == null
      || configuration.ID_MODEL == GuiConnector.getParams["submap"]) {
    if (GuiConnector.getParams["x"] != undefined
        && GuiConnector.getParams["y"] != undefined) {
      ServerConnector.setCenterCoordinateX(GuiConnector.getParams["x"]);
      ServerConnector.setCenterCoordinateY(GuiConnector.getParams["y"]);
    }
    if (GuiConnector.getParams["zoom"] != undefined) {
      ServerConnector.setZoomLevel(GuiConnector.getParams["zoom"]);
    }
  }
}

function create(params) {  
  if (global.GuiConnector === undefined) {
    global.GuiConnector = OriginalGuiConnector;
    global.GuiConnector.init();
    global.ServerConnector = OriginalServerConnector;
    logger.setLevel("info");
  } else {
    logger.warn("global GuiConnector found");
  }

  var browser = functions.browser;
  if (browser.name == "IE") {
    if (browser.version <= 8 || browser.compatibilityMode) {
      var message = "This webpage works only with Internet Explorer version 9 or greater.\n"
          + "If you have Internet Explorer version 9 or greater and still see this message, please, turn the 'Compatibility modeoff:\n"
          + "Open Internet Explorer and press the Alt key on your keyboard.\n"
          + "Select 'Tools' menu item. \n"
          + "Select the 'Compatibility View' settings option. \n"
          + "Make sure the 'Display all websites in Compatibility View' check box is unchecked and that the 'Compatibility View; list of websites is cleared.\n"
          + "\n"
          + "Alternatively, please, use other browsers: Chrome, Firefox or Safari.";
      alert(message);
      logger.warn(message);
    }
  }

  processUrlGetParams();

  var result = new CustomMap(params);

  ServerConnector.setCustomMap(result);
  GuiConnector.showGoogleMap();

  if (params.dataCollections != null) {
    for (var i = 0; i < params.dataCollections.length; i++) {
      var collection = params.dataCollections[i];
      ServerConnector.addOverlayCollection(new OverlayCollection(result,
          collection.name, collection.allowSearchById,
          collection.allowGeneralSearch));
    }
    result.refreshOverlays();
  } else {
    logger.warn("No overlay collection defined");
  }

  if (GuiConnector.getParams["search"] != undefined) {
    GuiConnector.search(GuiConnector.getParams["search"]);
  }

  if (GuiConnector.getParams["comments"] == "on") {
    document.getElementById('comment_checkbox').click();
  }
  if (GuiConnector.getParams["layout"] != undefined) {
    document.getElementById('tabView:layoutForm3:hidden2').value = GuiConnector.getParams["layout"];
    getVisualizedLayoutDetails();
  }

  // when I try to hide legend from the beginning or in the same thread it's
  // hidden forever... ;/
  setTimeout(function() {
    GuiConnector.hideLegend();
    var submodelId = GuiConnector.getParams["submap"];
    if (submodelId != undefined) {
      _createSubmodelDialog([ {
        name : 'submodelId',
        value : submodelId
      } ]);
      // for some reason the call above is not sync (even though it's required)
      var waitingForResponse = setInterval(function() {
        if (GuiConnector.getJsPopupForSubmodelId(submodelId) != null) {
          GuiConnector.openDialog(submodelId);
          clearInterval(waitingForResponse);
          if (GuiConnector.getParams["zoom"] != undefined) {
            result
                .setZoom(submodelId, parseInt(GuiConnector.getParams["zoom"]));
          }
          if (GuiConnector.getParams["x"] != undefined
              && GuiConnector.getParams["y"] != undefined) {
            var x = GuiConnector.getParams["x"];
            var y = GuiConnector.getParams["y"];
            var point = new google.maps.Point(x, y);
            result.setCenter(submodelId, point);
          }
        }
      }, 100);
    }
  }, 0);

  return result;
}

var minerva = {
  create : create,
  Configuration : Configuration,
};

module.exports = minerva;
